@@ -123,7 +123,7 @@ impl Client {
         }
         self.data.auth_token = auth_token;
     }
-    pub fn login(&mut self, password: String) {
+    pub fn login(&mut self, password: String) -> Result<(), Value> {
         let should_req_well_known = match self.host.split(":").last().unwrap().parse::<usize>() {
             Ok(port) => {
                 if port != 443 {
@@ -160,8 +160,12 @@ impl Client {
             .into_json()
             .unwrap();
         //println!("{:#}", val);
+        if !val.clone().as_object().unwrap().contains_key("auth_token") {
+            return Err(val);
+        }
         self.data.auth_token = val["access_token"].as_str().unwrap().to_string();
         self.me = UserId::try_from(val["user_id"].as_str().unwrap()).unwrap();
+        Ok(())
     }
     pub fn get_me(&self) -> UserId {
         self.me.clone()
